@@ -43,7 +43,7 @@ class PlayStoreScraper:
 		apps = []
 
 		try:
-			result = requests.get(url).text
+			result = requests.get(url, headers={"Accept-Language": lang}).text
 			data = self.extract_json_block(result, "ds:3")
 			data = json.loads(data)
 		except json.JSONDecodeError:
@@ -318,7 +318,7 @@ class PlayStoreScraper:
 		:return generator:  A list (via a generator) of app details
 		"""
 		for app_id in app_ids:
-			yield self.get_app_details(app_id)
+			yield self.get_app_details(app_id, country=country, lang=lang)
 
 	def extract_json_block(self, html, block_id):
 		"""
